@@ -414,24 +414,6 @@ class SyncCache(object):
     def increment_page_score(self, page_id, increment=1):
         self.redis.zincrby('page-scores', page_id, increment)
 
-    def seized_pages_score(self):
-        pages = self.redis.zrange('page-scores', 0, -1, withscores=True)
-        self.redis.zremrangebyrank('page-scores', 0, -1)
-        return pages
-
-    def lock_update_pages_score(self, expiration):
-        return self.redis.lock('update-pages-score-lock', expiration)
-
-    def has_update_pages_lock(self, expiration):
-        lock = self.lock_update_pages_score(expiration)
-        has_acquired = lock.acquire(blocking=False)
-        if not has_acquired:
-            return None
-        return lock
-
-    def release_update_pages_lock(self, lock):
-        return lock.release()
-
     def get_limiter_buckets(self, active_domains, avg_links_per_page=10.0):
         available = []
         all_limiters = reversed(sorted(Limiter.get_limiters_for_domains(self.db, active_domains), key=lambda item: item.url))
