@@ -31,10 +31,12 @@ class ReviewHandler(BaseReviewHandler):
             return
 
         if not page:
-            self.set_status(404, 'Page with uuid of %s not found!' % page_uuid)
+            self.set_status(404, self._('Page UUID [%s] not found') % page_uuid)
             return
 
-        result = review.to_dict(self.application.fact_definitions, self.application.violation_definitions)
+        result = review.to_dict(self.application.fact_definitions,
+                                self.application.violation_definitions,
+                                self._)
         result.update({
             'violationPoints': review.get_violation_points(),
             'violationCount': review.violation_count,
@@ -51,7 +53,9 @@ class LastReviewsHandler(BaseReviewHandler):
 
         reviews_json = []
         for review in reviews:
-            review_dict = review.to_dict(self.application.fact_definitions, self.application.violation_definitions)
+            review_dict = review.to_dict(self.application.fact_definitions,
+                                         self.application.violation_definitions,
+                                         self._)
             data = {
                 'violationCount': review.violation_count,
             }
