@@ -2,57 +2,69 @@
 # -*- coding: utf-8 -*-
 
 from holmes.validators.base import Validator
+from holmes.utils import _
 
 
 class CSSRequestsValidator(Validator):
-    @classmethod
-    def get_requests_css_message(cls, value):
-        return 'This page has %d CSS request (%d over limit). ' \
-               'Having too many requests impose a tax in the ' \
-               'browser due to handshakes.' % (value['total_css_files'],
-                                               value['over_limit'])
-
-    @classmethod
-    def get_total_size_message(cls, value):
-        return 'There\'s %.2fkb of CSS in this page and that ' \
-               'adds up to more download time slowing down the ' \
-               'page rendering to the user.' % value
-
     @classmethod
     def get_violation_definitions(cls):
         return {
             'total.requests.css': {
-                'title': 'Too many CSS requests',
-                'description': cls.get_requests_css_message,
-                'category': 'Performance',
-                'generic_description': (
+                'title': _('Too many CSS requests'),
+                'description': _(
+                    'This page has %(total_css_files)d CSS request '
+                    '(%(over_limit)d over limit). Having too many '
+                    'requests impose a tax in the browser due to handshakes.'),
+                'category': _('Performance'),
+                'generic_description': _(
                     'Pages with too many CSS requests aren\'t good to '
                     'performance. Overflowing this limit of requests can '
                     'impose a tax in the browser due to handshakes. This '
                     'limit of requests per page is configurable.'
                 ),
+                'unit': 'number'
             },
             'total.size.css': {
-                'title': 'CSS size in kb is too big',
-                'description': cls.get_total_size_message,
-                'category': 'Performance',
-                'generic_description': (
+                'title': _('CSS size in kb is too big'),
+                'description': _(
+                    'There\'s %.2fkb of CSS in this page and that '
+                    'adds up to more download time slowing down the '
+                    'page rendering to the user.'),
+                'category': _('Performance'),
+                'generic_description': _(
                     'Pages with too big CSS files aren\'t good to performance. '
                     'Having this limit of file sizes overflow adds up to more '
                     'download time slowing down the page rendering to the user. '
                     'This limit of requests per page is configurable.'
                 ),
+                'unit': 'number'
             },
         }
 
+    @classmethod
+    def get_default_violations_values(cls, config):
+        return {
+            'total.requests.css': {
+                'value': config.MAX_CSS_REQUESTS_PER_PAGE,
+                'description': config.get_description('MAX_CSS_REQUESTS_PER_PAGE')
+            },
+            'total.size.css': {
+                'value': config.MAX_CSS_KB_PER_PAGE_AFTER_GZIP,
+                'description': config.get_description('MAX_CSS_KB_PER_PAGE_AFTER_GZIP')
+            }
+        }
+
     def validate(self):
+        max_requests_css = self.get_violation_pref('total.requests.css')
+
+        max_size_css_gzipped = self.get_violation_pref('total.size.css')
+
         total_css_files = self.get_total_requests_css()
         total_size_gzip = self.get_total_size_css_gzipped()
 
-        max_requests = self.reviewer.config.MAX_CSS_REQUESTS_PER_PAGE
-        over_limit = total_css_files - max_requests
+        over_limit = total_css_files - max_requests_css
 
-        if total_css_files > self.reviewer.config.MAX_CSS_REQUESTS_PER_PAGE:
+        if total_css_files > max_requests_css:
             self.add_violation(
                 key='total.requests.css',
                 value={
@@ -62,13 +74,11 @@ class CSSRequestsValidator(Validator):
                 points=5 * over_limit
             )
 
-        max_kb_gzip = self.reviewer.config.MAX_CSS_KB_PER_PAGE_AFTER_GZIP
-
-        if total_size_gzip > max_kb_gzip:
+        if total_size_gzip > max_size_css_gzipped:
             self.add_violation(
                 key='total.size.css',
                 value=total_size_gzip,
-                points=int(total_size_gzip - max_kb_gzip)
+                points=int(total_size_gzip - max_size_css_gzipped)
             )
 
     def get_css_requests(self):
